@@ -173,6 +173,7 @@ check_sessions();
 check_uploads_ids();
 check_all_files();
 check_data_sources();
+fix_session_permissions();
 fix_sqlite_permissions() if $type =~ /sqlite/i;
 
 $database->disconnect;
@@ -486,6 +487,14 @@ sub fix_permissions {
     }
 }
 
+sub fix_session_permissions {
+    print STDERR "Fixing permissions in sessions directory\n";
+    my $globals     = Bio::Graphics::Browser2->open_globals;
+    my $session_dir = $globals->session_dir;
+    my $webuser     = GBrowse::ConfigData->config('wwwuser');
+    system "sudo chown -R $webuser $session_dir";
+}
+
 sub fix_sqlite_permissions {
     my (undef, $db_name) = $dsn =~ /.*:(database=)?([^;]+)/;
     $db_name ||= "gbrowse_login";
