@@ -30,6 +30,8 @@ END
 
    SHOWING_FROM_TO => '%s from %s:%s..%s',
 
+   CURRENTLY_SHOWING => '(Currently showing %s)',
+
    INSTRUCTIONS      => 'Instructions',
 
    HIDE              => 'Hide',
@@ -67,7 +69,6 @@ Your request timed out.  You may have selected a region that is too large to dis
 Either turn off some tracks or try a smaller region.  If you are experiencing persistent
 timeouts, please press the red "Reset" button.
 END
-   IPAD_BALLOON => 'Tap feature again for more details',
 
    GO       => 'Go',
 
@@ -91,10 +92,6 @@ END
 
    DOWNLOAD         => 'Download',
 
-   DOWNLOAD_ALL     => 'Download entire dataset',
-
-   TRACK_ID         => 'Track ID=<b>%s</b>',
-
    DISPLAY_SETTINGS => 'Display Settings',
 
    TRACKS   => 'Tracks',
@@ -103,23 +100,34 @@ END
 # FAVORITE MENU LINKS
    FAVORITES => 'Show Favorites Only',		
     
-   SHOWALL   => 'Show All',
+   SHOWALL   => 'Show Favorites and Others',
+
+   SHOW_ACTIVE => 'Show Active Tracks Only',
+
+   SHOW_ACTIVE_INACTIVE => 'Show Active & Inactive Tracks',
 
    REFRESH_FAV   => 'Refresh Favorites',
     
    CLEAR_FAV     => 'Clear All Favorites',
 
+   SHOW_ACTIVE_TRACKS     => 'Show Active Tracks Only',
+
    ADDED_TO     => 'Add track to favorites',
 
 #############
-   SNAPSHOT_FORM   => 'Snapshot Name',
    
+   SNAPSHOT_FORM   => 'Snapshot Name',
+
    CURRENT_SNAPSHOT => 'Current Snapshot:',
 
    TIMESTAMP      => 'Snapshot Timestamp [GMT]',
 
    SNAPSHOT_SELECT => 'Snapshots',
 
+   SAVE_SNAPSHOT   => 'Save Snapshot',
+
+   LOAD_SNAPSHOT   => 'Load Snapshot',
+
    SELECT_TRACKS   => 'Select Tracks',
 
    TRACK_SELECT   => 'Search for Specific Tracks',
@@ -160,8 +168,6 @@ END
 
    SELECT_SUBTRACKS   => 'showing %d/%d subtracks',
 
-   NO_TRACK_CITATION => 'There is no additional information about this track.',
-
    EDIT       => 'Edit File...',
 
    DELETE     => 'Delete File',
@@ -232,7 +238,9 @@ END
 
    REMOTE_TITLE => 'Add remote annotations',
 
-   IPAD_BALLOON => 'Tap features twice to see more details',
+   #ipad
+   IPAD_BALLOON => '\nTap feature again to see more details',
+   #
 
    REMOTE_URL   => 'Enter remote track URL',
 
@@ -250,6 +258,8 @@ END
 
    FEATURES_CLIPPED => 'Showing %s of %s features',
 
+   FEATURES_CLIPPED_MAX => 'Showing %s of >%s features',
+
    FILE_INFO    => 'Last modified %s.  Annotated landmarks: %s',
 
    FOOTER_1     => <<END,
@@ -403,7 +413,6 @@ END
 
  ADD_DESCRIPTION    => 'Click to add a description',
  ADD_TITLE          => 'Click to edit the title',
- EDIT_LABEL         => 'Click to view track. Shift or control-click to edit.',
  NO_DESCRIPTION     => 'No description',
 
  CONFIGURATION     => 'Configuration',
@@ -414,7 +423,7 @@ END
 
  HEIGHT           => 'Height',
 
- PACKING          => 'Packing',
+ PACKING          => 'Spacing',
 
  GLYPH            => 'Shape',
 
@@ -489,6 +498,10 @@ END
 
  SHOWING_SUBTRACKS  => '(<i>Showing %d of %d subtracks</i>)',
 
+ OVERLAP            => 'Semi-transparent overlap',
+
+ AUTO_COLORS        => 'Set colors automatically',
+
  SHARE_THIS_TRACK   => '<b>Share this track</b>',
 
  SHARE_ALL          => 'Share these tracks',
@@ -680,8 +693,9 @@ END
                                 '<br><br>To complete the account creation process and to log into your %s ' .
                                 'account, please type in your username and click the "Continue" button below.',
    MUST_TYPE_USERNAME        => 'You must type in your username to continue.',
-   INCORRECT_LINK            => 'The confirmation code provided is either incorrect or expired.<br> Please click continue to exit.',
+   INCORRECT_LINK            => 'The link provided is either incorrect or expired.<br> Please click continue to exit.',
    PENDING                   => 'pending',
+   
    WELCOME                   => 'Welcome, %s',
    LOG_OUT_DESC              => 'Click here to log out from %s',
    LOG_OUT                   => 'Log Out',
