@@ -21,10 +21,7 @@ sub config_dialog {
 
     my $state       = $render->state();
     my $data_source = $render->data_source();
-    my $seg      = $label =~ /:overview$/ ? $render->thin_whole_segment
-	          :$label =~ /:region$/   ? $render->thin_region_segment
-                  :$render->thin_segment;
-    my $length = eval{$seg->length}||0;
+    my $length      = $render->segment_length($label);
 
     eval 'require Bio::Graphics::Browser2::OptionPick; 1'
         unless Bio::Graphics::Browser2::OptionPick->can('new');
@@ -34,8 +31,12 @@ sub config_dialog {
     # summary options
     my $can_summarize = $data_source->can_summarize($label);
     my $summary_mode  = $data_source->show_summary($label,$length);
+    my $summary_length= $self->setting( $label => 'show summary' ,  $length, $summary_mode)    || 0;
+    my @thresh        = sort {$a<=>$b} ($data_source->semantic_thresholds($label),$summary_length);    
+    my $semantic_min  = (grep {$length >= $_} @thresh)[-1] || MIN; 
+    my $semantic_max  = (grep {$length < $_}  @thresh)[0]  || MAX; 
 
-    my $slabel           = $summary_mode ? $label : $data_source->semantic_label($label,$length);
+    my $slabel        = $summary_mode ? $label : $data_source->semantic_label($label,$length);
 
     if ($revert_to_defaults) {
 	$state->{features}{$label}{summary_override}  = {} if $summary_mode;
@@ -43,20 +44,25 @@ sub config_dialog {
 	delete $state->{features}{$label}{summary_mode_len};
     }
 
-    my $scaled_length  = $length/$render->details_mult;
     my $semantic_override = $render->find_override_region($state->{features}{$label}{semantic_override},$length);
     $semantic_override   ||= 0;
 
-    my ($semantic_level)   = $slabel =~ /(\d+)$/;
-    $semantic_level      ||= 0;
-    my @level              = map {
-	scalar $render->data_source->unit_label($_/$render->details_mult)
-    } split ':',($semantic_override || $semantic_level);
-    my $level              = join '..',@level;
+    # my ($semantic_level)   = $slabel =~ /(\d+)$/;
+    # $semantic_level      ||= 0;
+    # my @level              = map {
+    # 	scalar $render->data_source->unit_label($_)
+    # } split ':',($semantic_override || $semantic_level);
+    # my $level              = join '..',@level;
+    my ($low,$hi)   = $render->find_override_bounds($state->{features}{$label}{semantic_override},$length);
+    $semantic_min   = $low if defined $low;
+    $semantic_max   = $hi  if defined $hi;
+    my $level                = join '..',map {scalar $render->data_source->unit_label($_)} $semantic_min,$semantic_max;
 
     my $key = $render->label2key($label);
     $key .= $summary_mode      ? " (".$render->translate('FEATURE_SUMMARY').')'
-           :$level             ? " ($level)"
+	   :$level eq '0 bp'   ? ''
+	   :$level =~ /\.\./   ? " ($level)"
+           :$level             ? " (>=$level)"
 	   :'';
 
     my $override = $summary_mode 
@@ -65,7 +71,7 @@ sub config_dialog {
 
     my $return_html = start_html();
 
-    my $showing = $render->data_source->unit_label($scaled_length);
+    my $showing = $render->data_source->unit_label($length);
     my $title   = div({-class=>'config-title'},$key,br(),div({-style=>'font-size:9pt'},$render->translate('Currently_Showing',$showing)));
     my $dynamic = $render->translate('DYNAMIC_VALUE');
 
@@ -73,10 +79,10 @@ sub config_dialog {
     my $width         = $self->setting( $label => 'linewidth',      $length, $summary_mode )   || 1;
     my $glyph         = $self->setting( $label => 'glyph',          $length, $summary_mode )   || 'box';
     my $stranded      = $self->setting( $label => 'stranded',       $length, $summary_mode);
+    $stranded++      if $glyph eq 'gene';  # workaround a inconsistency in gene glyph behavior
     my $variance_band = $self->setting( $label => 'variance_band',  $length, $summary_mode);
     my $color_series  = $self->setting( $label => 'color_series',   $length, $summary_mode);
     my $limit         = $self->setting( $label => 'feature_limit' , $length, $summary_mode)    || 0;
-    my $summary_length= $self->setting( $label => 'show summary' , $length, $summary_mode) || 0;
     my $opacity       = $override->{'opacity'} || $self->setting($label => 'opacity',$length,$summary_mode) || 0.3;
 
     # options for wiggle & xy plots
@@ -534,27 +540,23 @@ END
 		      checkbox(
 			  -name    => 'conf_stranded',
 			  -override=> 1,
-			 -value   => 1,
+			  -value   => 1,
 			  -checked => defined $override->{'stranded'} 
-			  ? $override->{'stranded'} 
-			  : $stranded,
+			            ? $override->{'stranded'} 
+			            : $stranded,
 			  -label   => '',
 		      )
 		  )
         );
 
-    my ($low,$hi)   = $render->find_override_bounds($state->{features}{$label}{semantic_override},$scaled_length);
-    $low = $semantic_level unless defined $low;
-    $hi  ||= MAX;
-    my $mult = $render->details_mult;
     push @rows,TR({-class=>'general'},
 		  th( {-align => 'right' }, 
 		      $render->translate('APPLY_CONFIG')
 		      ),
 		  td(
-		      $self->region_size_menu('apply_semantic_low',$scaled_length,[$low/$mult,MIN],$low/$mult),
+		      $self->region_size_menu('apply_semantic_low',$length,[$semantic_min,MIN],$semantic_min),
 		      '-',
-		      $self->region_size_menu('apply_semantic_hi',$scaled_length,[$hi/$mult,MAX],$hi/$mult),
+		      $self->region_size_menu('apply_semantic_hi',$length,[$semantic_max,MAX],$semantic_max),
 		  )
 	) unless $summary_mode;
 
